@@ -7,7 +7,11 @@ def log(index: str, doc, params=None, headers=None):
         @wraps(func)
         def inner(*args, **kwargs):
             response, status_code = func(*args, **kwargs)
-            response, status_code = log_provider(response, status_code, index, doc, params, headers)
+            args = {
+                'args': args,
+                'kwargs': kwargs
+            }
+            response, status_code = log_provider(response, status_code, index, doc, args, params, headers)
             return response, status_code
 
         return inner
